@@ -6,12 +6,24 @@ Its basic goal is to present what can be done with this module and to
 ease its usage.
 """
 
-from mstrio.object_management import (Folder, full_search, get_my_personal_objects_contents,
-                                      get_predefined_folder_contents, get_search_results,
-                                      get_search_suggestions, list_folders, list_objects, Object,
-                                      PredefinedFolders, quick_search, quick_search_from_object,
-                                      SearchObject, SearchPattern, SearchResultsFormat,
-                                      start_full_search)
+from mstrio.object_management import (
+    Folder,
+    full_search,
+    get_my_personal_objects_contents,
+    get_predefined_folder_contents,
+    get_search_results,
+    get_search_suggestions,
+    list_folders,
+    list_objects,
+    Object,
+    PredefinedFolders,
+    quick_search,
+    quick_search_from_object,
+    SearchObject,
+    SearchPattern,
+    SearchResultsFormat,
+    start_full_search
+)
 from mstrio.project_objects import Dossier
 from mstrio.types import ObjectSubTypes, ObjectTypes
 from mstrio.utils.entity import Rights
@@ -46,12 +58,14 @@ list_folders(conn)
 get_my_personal_objects_contents(conn, project_id=PROJECT_ID)
 
 # get contents of a pre-defined folder in a specific folder
-get_predefined_folder_contents(conn, folder_type=PredefinedFolders.PUBLIC_REPORTS,
-                               project_id=PROJECT_ID)
+get_predefined_folder_contents(
+    conn, folder_type=PredefinedFolders.PUBLIC_REPORTS, project_id=PROJECT_ID
+)
 
 # create new folder in a particular folder
-new_folder = Folder.create(conn, name=FOLDER_NAME, parent=FOLDER_PARENT_ID,
-                           description=FOLDER_DESCRIPTION)
+new_folder = Folder.create(
+    conn, name=FOLDER_NAME, parent=FOLDER_PARENT_ID, description=FOLDER_DESCRIPTION
+)
 
 # get folder with a given ID
 folder = Folder(conn, id=FOLDER_ID)
@@ -64,8 +78,13 @@ contents_dict = folder.get_contents(to_dictionary=True)
 folder.alter(name=FOLDER_NAME, description=FOLDER_DESCRIPTION)
 
 # add ACL right to the folder for the user and propagate to children of folder
-folder.acl_add(Rights.EXECUTE, trustees=TRUSTED_USER_ID, denied=False, inheritable=True,
-               propagate_to_children=True)  # see utils/acl.py for Rights values
+folder.acl_add(
+    Rights.EXECUTE,
+    trustees=TRUSTED_USER_ID,
+    denied=False,
+    inheritable=True,
+    propagate_to_children=True
+)  # see utils/acl.py for Rights values
 
 # remove ACL from the folder for the user
 folder.acl_remove(Rights.EXECUTE, trustees=TRUSTED_USER_ID, denied=False, inheritable=True)
@@ -117,52 +136,81 @@ search_object = SearchObject(conn, id=OBJECT_ID)
 
 # get search suggestions with the pattern set performed in all unique projects
 # across the cluster (it takes effect only in I-Server with cluster nodes)
-suggestions = get_search_suggestions(conn, project=PROJECT_ID, key=SEARCH_PATTERN, max_results=20,
-                                     cross_cluster=True)
+suggestions = get_search_suggestions(
+    conn, project=PROJECT_ID, key=SEARCH_PATTERN, max_results=20, cross_cluster=True
+)
 
 # use the stored results of the Quick Search engine to return search results
 # and display them as a list (in this particular case all reports which name
 # begins with 'A')
-objects = quick_search(conn, PROJECT_ID, name='A', pattern=SearchPattern.BEGIN_WITH,
-                       object_types=[ObjectTypes.REPORT_DEFINITION])
+objects = quick_search(
+    conn,
+    PROJECT_ID,
+    name='A',
+    pattern=SearchPattern.BEGIN_WITH,
+    object_types=[ObjectTypes.REPORT_DEFINITION]
+)
 
 # perform quick search based on a predefined Search Object (include ancestors
 # and acl of returned objects)
-objects = quick_search_from_object(conn, PROJECT_ID, search_object, include_ancestors=True,
-                                   include_acl=True)
+objects = quick_search_from_object(
+    conn, PROJECT_ID, search_object, include_ancestors=True, include_acl=True
+)
 
 # search the metadata for objects in a specific project that match specific
 # search criteria (e.g. super cubes which name ends with `cube`) and save the
 # results in I-Server memory
-start_dict = start_full_search(conn, PROJECT_ID, name='cube', pattern=SearchPattern.END_WITH,
-                               object_types=ObjectSubTypes.SUPER_CUBE)
+start_dict = start_full_search(
+    conn,
+    PROJECT_ID,
+    name='cube',
+    pattern=SearchPattern.END_WITH,
+    object_types=ObjectSubTypes.SUPER_CUBE
+)
 
 # Retrieve the results of a full metadata search in a tree format which were
 # previously obtained by `start_full_search`
-results = get_search_results(conn, search_id=start_dict['id'],
-                             results_format=SearchResultsFormat.TREE)
+results = get_search_results(
+    conn, search_id=start_dict['id'], results_format=SearchResultsFormat.TREE
+)
 
 # perform full search in one call (instead of the two steps presented above).
 # Get all documents which name contains `document` and return in a list format.
 # Perform search only in the root folder and its subfolders.
-results = full_search(conn, PROJECT_ID, name='document', pattern=SearchPattern.CONTAINS,
-                      object_types=ObjectTypes.DOCUMENT_DEFINITION, root=FOLDER_ID)
+results = full_search(
+    conn,
+    PROJECT_ID,
+    name='document',
+    pattern=SearchPattern.CONTAINS,
+    object_types=ObjectTypes.DOCUMENT_DEFINITION,
+    root=FOLDER_ID
+)
 
 # return cubes that are used by the given dossier (it can be performed with the
 # function `full_search` or method `get_connected_cubes` from `Document` class
 # or method `get_dependencies` from `Entity` class)
 cubes = Dossier(conn, id=OBJECT_ID).get_connected_cubes()
 cubes = Dossier(conn, id=OBJECT_ID).list_dependencies(
-    project=PROJECT_ID, object_types=[ObjectSubTypes.OLAP_CUBE, ObjectSubTypes.SUPER_CUBE])
-cubes = full_search(conn, project=PROJECT_ID,
-                    object_types=[ObjectSubTypes.OLAP_CUBE,
-                                  ObjectSubTypes.SUPER_CUBE], used_by_object_id=OBJECT_ID,
-                    used_by_object_type=ObjectTypes.DOCUMENT_DEFINITION)
+    project=PROJECT_ID, object_types=[ObjectSubTypes.OLAP_CUBE, ObjectSubTypes.SUPER_CUBE]
+)
+cubes = full_search(
+    conn,
+    project=PROJECT_ID,
+    object_types=[ObjectSubTypes.OLAP_CUBE, ObjectSubTypes.SUPER_CUBE],
+    used_by_object_id=OBJECT_ID,
+    used_by_object_type=ObjectTypes.DOCUMENT_DEFINITION
+)
 
 # we can also list cubes that use given dossier
 cubes_using_dossier = Dossier(conn, id=OBJECT_ID).list_dependents(
-    project=PROJECT_ID, object_types=[ObjectSubTypes.OLAP_CUBE, ObjectSubTypes.SUPER_CUBE])
+    project=PROJECT_ID, object_types=[ObjectSubTypes.OLAP_CUBE, ObjectSubTypes.SUPER_CUBE]
+)
 
 # get all objects that use (also recursive) metric with given id
-objects = full_search(conn, project=PROJECT_ID, uses_object_id=OBJECT_ID,
-                      uses_object_type=ObjectTypes.METRIC, uses_recursive=True)
+objects = full_search(
+    conn,
+    project=PROJECT_ID,
+    uses_object_id=OBJECT_ID,
+    uses_object_type=ObjectTypes.METRIC,
+    uses_recursive=True
+)
