@@ -8,7 +8,9 @@ from .datasource_connection import (
     CharEncoding, DatasourceConnection, DriverType, ExecutionMode, list_datasource_connections
 )
 from .datasource_instance import (
-    DatasourceInstance, DatasourceType, list_connected_datasource_instances,
+    DatasourceInstance,
+    DatasourceType,
+    list_connected_datasource_instances,
     list_datasource_instances
 )
 from .datasource_login import DatasourceLogin, list_datasource_logins
