@@ -6,6 +6,8 @@ from mstrio.api import datasources, objects
 from mstrio.users_and_groups.user import User
 from mstrio.utils import helper
 from mstrio.utils.entity import CopyMixin, DeleteMixin, Entity, ObjectTypes
+from mstrio.utils.helper import get_args_from_func, get_default_args_from_func
+from mstrio.utils.version_helper import class_version_handler, method_version_handler
 
 if TYPE_CHECKING:
     from mstrio.connection import Connection
@@ -13,9 +15,10 @@ if TYPE_CHECKING:
 logger = logging.getLogger(__name__)
 
 
-def list_datasource_logins(connection: "Connection", to_dictionary: bool = False,
-                           limit: int = None,
-                           **filters) -> Union[List["DatasourceLogin"], List[dict]]:
+@method_version_handler('11.2.0500')
+def list_datasource_logins(
+    connection: "Connection", to_dictionary: bool = False, limit: int = None, **filters
+) -> Union[List["DatasourceLogin"], List[dict]]:
     """Get list of DatasourceLogin objects or dicts. Optionally filter the
     logins by specifying filters.
 
@@ -40,6 +43,7 @@ def list_datasource_logins(connection: "Connection", to_dictionary: bool = False
     )
 
 
+@class_version_handler('11.2.0500')
 class DatasourceLogin(Entity, CopyMixin, DeleteMixin):
     """A user login configuration object to access a particular datasource. Also
     formerly known as database login.
@@ -64,15 +68,26 @@ class DatasourceLogin(Entity, CopyMixin, DeleteMixin):
     _OBJECT_TYPE = ObjectTypes.DBLOGIN
     _FROM_DICT_MAP = {**Entity._FROM_DICT_MAP, 'owner': User.from_dict}
     _API_GETTERS = {
-        ('abbreviation', 'type', 'subtype', 'ext_type', 'version', 'owner', 'icon_path',
-         'view_media', 'ancestors', 'certified_info', 'acl'): objects.get_object_info,
+        (
+            'abbreviation',
+            'type',
+            'subtype',
+            'ext_type',
+            'version',
+            'owner',
+            'icon_path',
+            'view_media',
+            'ancestors',
+            'certified_info',
+            'acl'
+        ): objects.get_object_info,
         ('id', 'name', 'description', 'username', 'date_created', 'date_modified',
          'acg'): datasources.get_datasource_login
     }
     _API_PATCH: dict = {
         ("abbreviation"): (objects.update_object, "partial_put"),
-        ("name", "username", "description", "password"):
-            (datasources.update_datasource_login, "patch")
+        ("name", "username", "description",
+         "password"): (datasources.update_datasource_login, "patch")
     }
     _PATCH_PATH_TYPES = {"name": str, "username": str, "description": str, "password": str}
 
@@ -83,8 +98,9 @@ class DatasourceLogin(Entity, CopyMixin, DeleteMixin):
             raise ValueError("Please specify either 'id' or 'name' parameter in the constructor.")
 
         if id is None:
-            objects_info = DatasourceLogin._list_datasource_logins(connection=connection,
-                                                                   name=name, to_dictionary=True)
+            objects_info = DatasourceLogin._list_datasource_logins(
+                connection=connection, name=name, to_dictionary=True
+            )
             if objects_info:
                 object_info, object_info["connection"] = objects_info[0], connection
                 self._init_variables(**object_info)
@@ -97,8 +113,13 @@ class DatasourceLogin(Entity, CopyMixin, DeleteMixin):
         super()._init_variables(**kwargs)
         self.username = kwargs.get("username")
 
-    def alter(self, name: str = None, username: str = None, description: str = None,
-              password: str = None) -> None:
+    def alter(
+        self,
+        name: str = None,
+        username: str = None,
+        description: str = None,
+        password: str = None
+    ) -> None:
         """Alter the datasource login properties.
 
         Args:
@@ -108,8 +129,8 @@ class DatasourceLogin(Entity, CopyMixin, DeleteMixin):
             password: database password to be used by the database login
         """
         func = self.alter
-        args = func.__code__.co_varnames[:func.__code__.co_argcount]
-        defaults = func.__defaults__  # type: ignore
+        args = get_args_from_func(func)
+        defaults = get_default_args_from_func(func)
         default_dict = dict(zip(args[-len(defaults):], defaults)) if defaults else {}
         local = locals()
         properties = {}
@@ -119,8 +140,14 @@ class DatasourceLogin(Entity, CopyMixin, DeleteMixin):
         self._alter_properties(**properties)
 
     @classmethod
-    def create(cls, connection: "Connection", name: str, username: str, password: str,
-               description: str = None) -> "DatasourceLogin":
+    def create(
+        cls,
+        connection: "Connection",
+        name: str,
+        username: str,
+        password: str,
+        description: str = None
+    ) -> "DatasourceLogin":
         """Create a new datasource login.
 
         Args:
@@ -134,10 +161,7 @@ class DatasourceLogin(Entity, CopyMixin, DeleteMixin):
             DatasourceConnection object.
         """
         body = {
-            "name": name,
-            "description": description,
-            "username": username,
-            "password": password
+            "name": name, "description": description, "username": username, "password": password
         }
         body = helper.delete_none_values(body, recursion=True)
         response = datasources.create_datasource_login(connection, body).json()
@@ -149,12 +173,16 @@ class DatasourceLogin(Entity, CopyMixin, DeleteMixin):
         return cls.from_dict(source=response, connection=connection)
 
     @classmethod
-    def _list_datasource_logins(cls, connection: "Connection", to_dictionary: bool = False,
-                                limit: int = None,
-                                **filters) -> Union[List["DatasourceLogin"], List[dict]]:
-        objects = helper.fetch_objects(connection=connection,
-                                       api=datasources.get_datasource_logins,
-                                       dict_unpack_value="logins", limit=limit, filters=filters)
+    def _list_datasource_logins(
+        cls, connection: "Connection", to_dictionary: bool = False, limit: int = None, **filters
+    ) -> Union[List["DatasourceLogin"], List[dict]]:
+        objects = helper.fetch_objects(
+            connection=connection,
+            api=datasources.get_datasource_logins,
+            dict_unpack_value="logins",
+            limit=limit,
+            filters=filters
+        )
         if to_dictionary:
             return objects
         else:
