@@ -11,9 +11,14 @@ from mstrio.types import ObjectSubTypes, ObjectTypes
 from mstrio.users_and_groups import User
 from mstrio.utils.entity import CopyMixin, Entity, EntityBase, MoveMixin
 from mstrio.utils.helper import (
-    exception_handler, fetch_objects_async, get_args_from_func, get_enum_val, get_objects_id,
+    exception_handler,
+    fetch_objects_async,
+    get_args_from_func,
+    get_enum_val,
+    get_objects_id,
     merge_id_and_type
 )
+from mstrio.utils.version_helper import class_version_handler, method_version_handler
 
 if TYPE_CHECKING:
     from mstrio.types import TypeOrSubtype
@@ -21,6 +26,7 @@ if TYPE_CHECKING:
 logger = logging.getLogger(__name__)
 
 
+@class_version_handler('11.3.0100')
 class SearchObject(Entity, CopyMixin, MoveMixin):
     """Search object describing criteria that specify a search for objects.
 
@@ -59,14 +65,22 @@ class SearchObject(Entity, CopyMixin, MoveMixin):
         super().__init__(connection=connection, object_id=id)
 
 
-def quick_search(connection: Connection, project: Optional[Union[Project, str]] = None,
-                 name: Optional[str] = None, root: Optional[str] = None,
-                 pattern: Union[SearchPattern, int] = SearchPattern.CONTAINS,
-                 object_types: Optional["TypeOrSubtype"] = None, get_ancestors: bool = False,
-                 cross_cluster: bool = False, hidden: Optional[bool] = None,
-                 certified_status: CertifiedStatus = CertifiedStatus.ALL,
-                 limit: Optional[int] = None, offset: Optional[int] = None,
-                 to_dictionary: bool = True):
+@method_version_handler('11.3.0000')
+def quick_search(
+    connection: Connection,
+    project: Optional[Union[Project, str]] = None,
+    name: Optional[str] = None,
+    root: Optional[str] = None,
+    pattern: Union[SearchPattern, int] = SearchPattern.CONTAINS,
+    object_types: Optional["TypeOrSubtype"] = None,
+    get_ancestors: bool = False,
+    cross_cluster: bool = False,
+    hidden: Optional[bool] = None,
+    certified_status: CertifiedStatus = CertifiedStatus.ALL,
+    limit: Optional[int] = None,
+    offset: Optional[int] = None,
+    to_dictionary: bool = True
+):
     """Use the stored results of the Quick Search engine to return
      search results and display them as a list. The Quick Search
      engine periodically indexes the metadata and stores the results in memory,
@@ -119,24 +133,38 @@ def quick_search(connection: Connection, project: Optional[Union[Project, str]]
         object_types = [get_enum_val(t, (ObjectTypes, ObjectSubTypes)) for t in object_types]
     pattern = get_enum_val(pattern, SearchPattern)
     certified_status = get_enum_val(certified_status, CertifiedStatus)
-    resp = browsing.get_quick_search_result(connection, project_id=project_id, name=name,
-                                            pattern=pattern, object_types=object_types, root=root,
-                                            get_ancestors=get_ancestors, hidden=hidden,
-                                            cross_cluster=cross_cluster, limit=limit,
-                                            certified_status=certified_status, offset=offset)
+    resp = browsing.get_quick_search_result(
+        connection,
+        project_id=project_id,
+        name=name,
+        pattern=pattern,
+        object_types=object_types,
+        root=root,
+        get_ancestors=get_ancestors,
+        hidden=hidden,
+        cross_cluster=cross_cluster,
+        limit=limit,
+        certified_status=certified_status,
+        offset=offset
+    )
     objects = resp.json()["result"]
     if to_dictionary:
         return objects
     return map_objects_list(connection, objects)
 
 
-def quick_search_from_object(connection: Connection, project: Union[Project, str],
-                             search_object: Union[SearchObject, str],
-                             include_ancestors: bool = False, include_acl: bool = False,
-                             subtypes: Optional[Union[ObjectSubTypes, List[ObjectSubTypes], int,
-                                                      List[int]]] = None,
-                             limit: Optional[int] = None, offset: Optional[int] = None,
-                             to_dictionary: bool = True):
+@method_version_handler('11.3.0100')
+def quick_search_from_object(
+    connection: Connection,
+    project: Union[Project, str],
+    search_object: Union[SearchObject, str],
+    include_ancestors: bool = False,
+    include_acl: bool = False,
+    subtypes: Optional[Union[ObjectSubTypes, List[ObjectSubTypes], int, List[int]]] = None,
+    limit: Optional[int] = None,
+    offset: Optional[int] = None,
+    to_dictionary: bool = True
+):
     """Perform a quick search based on a predefined Search Object.
     Use an existing search object for Quick Search engine to return
     search results and display them as a list.
@@ -167,20 +195,30 @@ def quick_search_from_object(connection: Connection, project: Union[Project, str
     project_id = get_objects_id(project, Project)
     search_object_id = get_objects_id(search_object, SearchObject)
     subtypes = get_enum_val(subtypes, ObjectSubTypes)
-    resp = browsing.get_quick_search_result_from_object(connection, project_id, search_object_id,
-                                                        subtypes=subtypes,
-                                                        include_ancestors=include_ancestors,
-                                                        include_acl=include_acl, limit=limit,
-                                                        offset=offset)
+    resp = browsing.get_quick_search_result_from_object(
+        connection,
+        project_id,
+        search_object_id,
+        subtypes=subtypes,
+        include_ancestors=include_ancestors,
+        include_acl=include_acl,
+        limit=limit,
+        offset=offset
+    )
     objects = resp.json()["result"]
     if to_dictionary:
         return objects
     return map_objects_list(connection, objects)
 
 
-def get_search_suggestions(connection: Connection, project: Optional[Union[Project, str]] = None,
-                           key: Optional[str] = None, max_results: int = 4,
-                           cross_cluster: Optional[bool] = None) -> List[str]:
+@method_version_handler('11.3.0000')
+def get_search_suggestions(
+    connection: Connection,
+    project: Optional[Union[Project, str]] = None,
+    key: Optional[str] = None,
+    max_results: int = 4,
+    cross_cluster: Optional[bool] = None
+) -> List[str]:
     """Request search suggestions from the server.
 
     Args:
@@ -200,26 +238,37 @@ def get_search_suggestions(connection: Connection, project: Optional[Union[Proje
     """
     project_id = get_objects_id(project, Project)
     return browsing.get_search_suggestions(
-        connection=connection, project_id=project_id, key=key, count=max_results,
-        is_cross_cluster=cross_cluster).json().get('suggestions')
+        connection=connection,
+        project_id=project_id,
+        key=key,
+        count=max_results,
+        is_cross_cluster=cross_cluster
+    ).json().get('suggestions')
 
 
-def full_search(connection: Connection, project: Optional[Union[Project, str]] = None,
-                name: Optional[str] = None, pattern: Union[SearchPattern,
-                                                           int] = SearchPattern.CONTAINS,
-                domain: Union[SearchDomain,
-                              int] = SearchDomain.PROJECT, root: Optional[str] = None,
-                object_types: Optional["TypeOrSubtype"] = None,
-                uses_object_id: Optional[Union[EntityBase, str]] = None,
-                uses_object_type: Optional[Union[ObjectTypes, int]] = None,
-                uses_recursive: bool = False, uses_one_of: bool = False,
-                used_by_object_id: Optional[Union[EntityBase, str]] = None,
-                used_by_object_type: Optional[Union[ObjectTypes, str]] = None,
-                used_by_recursive: bool = False, used_by_one_of: bool = False,
-                results_format: Union[SearchResultsFormat, str] = SearchResultsFormat.LIST,
-                limit: Optional[int] = None, offset: Optional[int] = None,
-                to_dictionary: bool = True,
-                **filters) -> Union[List[dict], List[Entity]]:
+@method_version_handler('11.3.0000')
+def full_search(
+    connection: Connection,
+    project: Optional[Union[Project, str]] = None,
+    name: Optional[str] = None,
+    pattern: Union[SearchPattern, int] = SearchPattern.CONTAINS,
+    domain: Union[SearchDomain, int] = SearchDomain.PROJECT,
+    root: Optional[str] = None,
+    object_types: Optional["TypeOrSubtype"] = None,
+    uses_object_id: Optional[Union[EntityBase, str]] = None,
+    uses_object_type: Optional[Union[ObjectTypes, int]] = None,
+    uses_recursive: bool = False,
+    uses_one_of: bool = False,
+    used_by_object_id: Optional[Union[EntityBase, str]] = None,
+    used_by_object_type: Optional[Union[ObjectTypes, str]] = None,
+    used_by_recursive: bool = False,
+    used_by_one_of: bool = False,
+    results_format: Union[SearchResultsFormat, str] = SearchResultsFormat.LIST,
+    limit: Optional[int] = None,
+    offset: Optional[int] = None,
+    to_dictionary: bool = True,
+    **filters
+) -> Union[List[dict], List[Entity]]:
     """Perform a full metadata search and return results.
 
     Args:
@@ -291,18 +340,24 @@ def full_search(connection: Connection, project: Optional[Union[Project, str]] =
     return get_search_results(**search_result_params)
 
 
-def start_full_search(connection: Connection, project: Optional[Union[Project, str]] = None,
-                      name: Optional[str] = None, object_types: Optional["TypeOrSubtype"] = None,
-                      pattern: Union[SearchPattern, int] = SearchPattern.CONTAINS,
-                      domain: Union[SearchDomain,
-                                    int] = SearchDomain.PROJECT, root: Optional[str] = None,
-                      uses_object_id: Optional[Union[EntityBase, str]] = None,
-                      uses_object_type: Optional[Union[ObjectTypes, ObjectSubTypes, int]] = None,
-                      uses_recursive: bool = False, uses_one_of: bool = False,
-                      used_by_object_id: Optional[Union[EntityBase, str]] = None,
-                      used_by_object_type: Optional[Union[ObjectTypes, ObjectSubTypes,
-                                                          int]] = None,
-                      used_by_recursive: bool = False, used_by_one_of: bool = False) -> dict:
+@method_version_handler('11.3.0000')
+def start_full_search(
+    connection: Connection,
+    project: Optional[Union[Project, str]] = None,
+    name: Optional[str] = None,
+    object_types: Optional["TypeOrSubtype"] = None,
+    pattern: Union[SearchPattern, int] = SearchPattern.CONTAINS,
+    domain: Union[SearchDomain, int] = SearchDomain.PROJECT,
+    root: Optional[str] = None,
+    uses_object_id: Optional[Union[EntityBase, str]] = None,
+    uses_object_type: Optional[Union[ObjectTypes, ObjectSubTypes, int]] = None,
+    uses_recursive: bool = False,
+    uses_one_of: bool = False,
+    used_by_object_id: Optional[Union[EntityBase, str]] = None,
+    used_by_object_type: Optional[Union[ObjectTypes, ObjectSubTypes, int]] = None,
+    used_by_recursive: bool = False,
+    used_by_one_of: bool = False
+) -> dict:
     """Search the metadata for objects in a specific project that
     match specific search criteria, and save the results in IServer memory.
 
@@ -358,13 +413,17 @@ def start_full_search(connection: Connection, project: Optional[Union[Project, s
     if uses_object_id and used_by_object_id:
         exception_handler(
             msg="It is not allowed to use both ‘uses_object’ and ‘used_by_object’ in one request.",
-            exception_type=AttributeError)
+            exception_type=AttributeError
+        )
 
     uses_object = merge_id_and_type(
-        uses_object_id, uses_object_type,
-        "Please provide both `uses_object_id` and `uses_object_type`.") if uses_object_id else None
+        uses_object_id,
+        uses_object_type,
+        "Please provide both `uses_object_id` and `uses_object_type`."
+    ) if uses_object_id else None
     used_by_object = merge_id_and_type(
-        used_by_object_id, used_by_object_type,
+        used_by_object_id,
+        used_by_object_type,
         "Please provide both `used_by_object_id` and `uses_object_type`."
     ) if used_by_object_id else None
 
@@ -393,11 +452,17 @@ def start_full_search(connection: Connection, project: Optional[Union[Project, s
     return resp.json()
 
 
-def get_search_results(connection: Connection, search_id: str,
-                       project: Optional[Union[Project, str]] = None,
-                       results_format: SearchResultsFormat = SearchResultsFormat.LIST,
-                       limit: Optional[int] = None, offset: Optional[int] = None,
-                       to_dictionary: bool = False, **filters):
+@method_version_handler('11.3.0000')
+def get_search_results(
+    connection: Connection,
+    search_id: str,
+    project: Optional[Union[Project, str]] = None,
+    results_format: SearchResultsFormat = SearchResultsFormat.LIST,
+    limit: Optional[int] = None,
+    offset: Optional[int] = None,
+    to_dictionary: bool = False,
+    **filters
+):
     """Retrieve the results of a full metadata search previously stored in
     an instance in IServer memory, may be obtained by `start_full_search`.
 
@@ -435,10 +500,15 @@ def get_search_results(connection: Connection, search_id: str,
     return _get_search_result_list_format(**get_result_params)
 
 
-def _get_search_result_list_format(connection: Connection, search_id: str,
-                                   project_id: Optional[str] = None, limit: Optional[int] = None,
-                                   offset: Optional[int] = None,
-                                   to_dictionary: bool = True, **filters):
+def _get_search_result_list_format(
+    connection: Connection,
+    search_id: str,
+    project_id: Optional[str] = None,
+    limit: Optional[int] = None,
+    offset: Optional[int] = None,
+    to_dictionary: bool = True,
+    **filters
+):
     from mstrio.utils.object_mapping import map_objects_list
     objects = fetch_objects_async(
         connection=connection,
@@ -457,9 +527,13 @@ def _get_search_result_list_format(connection: Connection, search_id: str,
     return map_objects_list(connection, objects)
 
 
-def _get_search_result_tree_format(connection: Connection, search_id: str,
-                                   project_id: Optional[str] = None, limit: Optional[int] = None,
-                                   offset: Optional[int] = None):
+def _get_search_result_tree_format(
+    connection: Connection,
+    search_id: str,
+    project_id: Optional[str] = None,
+    limit: Optional[int] = None,
+    offset: Optional[int] = None
+):
     resp = browsing.get_search_results_tree_format(
         connection=connection,
         search_id=search_id,
